@@ -15,11 +15,11 @@ def send(source, target) -> dict:
 
     """
     # TODO re-queue failures w/ a logarithmic backoff
-    target = webcli.uri(target)
-    endpoint = webcli.get(target).discover_link("webmention")
+    target = webagt.uri(target)
+    endpoint = webagt.get(target).discover_link("webmention")
     if not endpoint:
         raise EndpointNotFound(target)
-    return webcli.post(data={"source": source, "target": target}).json
+    return webagt.post(data={"source": source, "target": target}).json
 
 
 def receive(source, target):
